from distutils.core import setup
setup(
name = "list_print",
version = "1.0.1",
py_modules = "list_print",
author = "VenkatRayaprolu",
author_email = "rvramanamurty@gmail.com",
description = "Module to print the list"
)

